summaryrefslogtreecommitdiff
path: root/examples/register_account.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/register_account.py')
-rwxr-xr-xexamples/register_account.py18
1 files changed, 9 insertions, 9 deletions
diff --git a/examples/register_account.py b/examples/register_account.py
index 422e5602..199f697c 100755
--- a/examples/register_account.py
+++ b/examples/register_account.py
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
SleekXMPP: The Sleek XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
- This file is part of SleekXMPP.
+ This file is part of Slixmpp.
See the file LICENSE for copying permission.
"""
@@ -14,21 +14,21 @@ import logging
import getpass
from optparse import OptionParser
-import sleekxmpp
-from sleekxmpp.exceptions import IqError, IqTimeout
+import slixmpp
+from slixmpp.exceptions import IqError, IqTimeout
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
# throughout SleekXMPP, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
- from sleekxmpp.util.misc_ops import setdefaultencoding
+ from slixmpp.util.misc_ops import setdefaultencoding
setdefaultencoding('utf8')
else:
raw_input = input
-class RegisterBot(sleekxmpp.ClientXMPP):
+class RegisterBot(slixmpp.ClientXMPP):
"""
A basic bot that will attempt to register an account
@@ -40,7 +40,7 @@ class RegisterBot(sleekxmpp.ClientXMPP):
"""
def __init__(self, jid, password):
- sleekxmpp.ClientXMPP.__init__(self, jid, password)
+ slixmpp.ClientXMPP.__init__(self, jid, password)
# The session_start event will be triggered when
# the bot establishes its connection with the server
@@ -54,7 +54,7 @@ class RegisterBot(sleekxmpp.ClientXMPP):
# the basic registration fields, a data form, an
# out-of-band URL, or any combination. For more advanced
# cases, you will need to examine the fields provided
# and respond accordingly. SleekXMPP provides plugins
# for data forms and OOB links that will make that easier.
self.add_event_handler("register", self.register, threaded=True)
@@ -2,9 +2,9 @@
# -*- coding: utf-8 -*-
"""
- SleekXMPP: The Sleek XMPP Library
+ Slixmpp: The Slick XMPP Library
Copyright (C) 2010 Nathanael C. Fritz
@@ -14,21 +14,21 @@ import logging
# Python versions before 3.0 do not use UTF-8 encoding
# by default. To ensure that Unicode is handled properly
-# throughout SleekXMPP, we will set the default encoding
+# throughout Slixmpp, we will set the default encoding
# ourselves to UTF-8.
if sys.version_info < (3, 0):
@@ -54,7 +54,7 @@ class RegisterBot(sleekxmpp.ClientXMPP):
# out-of-band URL, or any combination. For more advanced
# cases, you will need to examine the fields provided
- # and respond accordingly. SleekXMPP provides plugins
+ # and respond accordingly. Slixmpp provides plugins
# for data forms and OOB links that will make that easier.
self.add_event_handler("register", self.register, threaded=True)